@@ -38,33 +38,43 @@ def generate_url(request):
     try:
         if 'width' in args:
             args['width'] = int(args['width'])
-    except ValueError, e:
+    except ValueError as e:
         error_message = "The width value '%s' is not an integer." % \
             args['width']
 
     try:
         if 'height' in args:
             args['height'] = int(args['height'])
-    except ValueError, e:
+    except ValueError as e:
         error_message = "The height value '%s' is not an integer." % \
             args['height']
 
     try:
         if 'crop_top' in args or 'crop_left' in args or 'crop_right' in args or 'crop_bottom' in args:
-            args['crop'] = ((int(args['crop_left']), int(args['crop_top'])),
-                    (int(args['crop_right']), int(args['crop_bottom'])))
-    except KeyError, e:
-        error_message = "Missing values for cropping. Expected all 'crop_left', 'crop_top', 'crop_right', 'crop_bottom' values."
-    except ValueError, e:
-        error_message = "Invalid values for cropping. Expected all 'crop_left', 'crop_top', 'crop_right', 'crop_bottom' to be integers."
+            args['crop'] = (
+                (int(args['crop_left']), int(args['crop_top'])),
+                (int(args['crop_right']), int(args['crop_bottom']))
+            )
+    except KeyError as e:
+        error_message = '''
+            Missing values for cropping.
+            Expected all 'crop_left', 'crop_top',
+            'crop_right', 'crop_bottom' values.
+        '''
+    except ValueError as e:
+        error_message = '''
+            Invalid values for cropping.
+            Expected all 'crop_left', 'crop_top',
+            'crop_right', 'crop_bottom' to be integers.
+        '''
 
     if error_message is not None:
         logging.warning(error_message)
         return HttpResponseBadRequest(error_message)
 
     try:
-        return HttpResponse(THUMBOR_SERVER + crypto.generate(**args).strip("/"), mimetype="text/plain")
-    except (ValueError, KeyError), e:
+        return HttpResponse(THUMBOR_SERVER + crypto.generate(**args).strip("/"), content_type="text/plain")
+    except (ValueError, KeyError) as e:
         error_message = str(e)
         logging.warning(error_message)
         return HttpResponseBadRequest(error_message)
