@@ -9,20 +9,20 @@
 # Copyright (c) 2011 Bernardo Heynemann heynemann@gmail.com
 
 '''libthumbor URL composer tests'''
+import sys
 from unittest import TestCase
 
-from thumbor.crypto import Crypto
-
 from libthumbor.url import url_for
 from libthumbor.url import unsafe_url
 
 IMAGE_URL = 'my.server.com/some/path/to/image.jpg'
 IMAGE_MD5 = '84996242f65a4d864aceb125e1c4c5ba'
 
-def decrypt_in_thumbor(key, encrypted):
-    '''Uses thumbor to decrypt libthumbor's encrypted URL'''
-    crypto = Crypto(key)
-    return crypto.decrypt(encrypted)
+# def decrypt_in_thumbor(key, encrypted):
+#     '''Uses thumbor to decrypt libthumbor's encrypted URL'''
+#     crypto = Cryptor(key)
+#     return crypto.decrypt(encrypted)
+
 
 def test_no_options_specified():
     '''test_no_options_specified
@@ -37,6 +37,7 @@ def test_no_options_specified():
 
     assert url == IMAGE_MD5, url
 
+
 def test_url_raises_if_no_url():
     '''test_url_raises_if_no_url
     Given
@@ -48,11 +49,12 @@ def test_url_raises_if_no_url():
     '''
     try:
         url_for()
-    except ValueError, err:
+    except ValueError as err:
         assert str(err) == 'The image_url argument is mandatory.'
         return True
     assert False, 'Should not have gotten this far'
 
+
 def test_url_width_height_1():
     '''test_url_width_height_1
     Given
@@ -67,6 +69,7 @@ def test_url_width_height_1():
 
     assert url == "300x0/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_url_width_height_2():
     '''test_url_width_height_2
     Given
@@ -81,6 +84,7 @@ def test_url_width_height_2():
 
     assert url == "0x300/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_url_width_height_3():
     '''test_url_width_height_3
     Given
@@ -98,6 +102,85 @@ def test_url_width_height_3():
 
     assert url == "200x300/84996242f65a4d864aceb125e1c4c5ba", url
 
+
+def test_url_width_height_4():
+    '''test_url_width_height_4
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a width of orig
+    When
+        I ask my library for an URL
+    Then
+        I get "origx0/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(width="orig", image_url=IMAGE_URL)
+
+    assert url == "origx0/84996242f65a4d864aceb125e1c4c5ba", url
+
+
+def test_url_width_height_5():
+    '''test_url_width_height_5
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a height of orig
+    When
+        I ask my library for an URL
+    Then
+        I get "0xorig/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(height="orig", image_url=IMAGE_URL)
+
+    assert url == "0xorig/84996242f65a4d864aceb125e1c4c5ba", url
+
+
+def test_url_width_height_6():
+    '''test_url_width_height_6
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a width of 100
+        And a height of orig
+    When
+        I ask my library for an URL
+    Then
+        I get "100xorig/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(width=100, height="orig", image_url=IMAGE_URL)
+
+    assert url == "100xorig/84996242f65a4d864aceb125e1c4c5ba", url
+
+
+def test_url_width_height_7():
+    '''test_url_width_height_7
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a height of 100
+        And a width of orig
+    When
+        I ask my library for an URL
+    Then
+        I get "origx100/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(width="orig", height=100, image_url=IMAGE_URL)
+
+    assert url == "origx100/84996242f65a4d864aceb125e1c4c5ba", url
+
+
+def test_url_width_height_8():
+    '''test_url_width_height_8
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a height of orig
+        And a width of orig
+    When
+        I ask my library for an URL
+    Then
+        I get "origxorig/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(width="orig", height="orig", image_url=IMAGE_URL)
+
+    assert url == "origxorig/84996242f65a4d864aceb125e1c4c5ba", url
+
+
 def test_smart_url():
     '''test_smart_url
     Given
@@ -117,6 +200,7 @@ def test_smart_url():
 
     assert url == "200x300/smart/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_fit_in_url():
     '''test_fit_in_url
     Given
@@ -136,6 +220,107 @@ def test_fit_in_url():
 
     assert url == "fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
 
+
+def test_adaptive_fit_in_url():
+    '''test_adaptive_fit_in_url
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a width of 200
+        And a height of 300
+        And the adaptive fit-in flag
+    When
+        I ask my library for an URL
+    Then
+        I get "adaptive-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(width=200,
+                  height=300,
+                  adaptive_fit_in=True,
+                  image_url=IMAGE_URL)
+
+    assert url == "adaptive-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
+
+
+def test_fit_in_fails_if_no_width_supplied():
+    try:
+        url_for(fit_in=True, image_url=IMAGE_URL)
+    except ValueError:
+        err = sys.exc_info()[1]
+        assert err is not None
+    else:
+        assert False, "Should not have gotten this far"
+
+
+def test_full_fit_in_fails_if_no_width_supplied():
+    try:
+        url_for(full_fit_in=True, image_url=IMAGE_URL)
+    except ValueError:
+        err = sys.exc_info()[1]
+        assert err is not None
+    else:
+        assert False, "Should not have gotten this far"
+
+
+def test_adaptive_fit_in_fails_if_no_width_supplied():
+    try:
+        url_for(adaptive_fit_in=True, image_url=IMAGE_URL)
+    except ValueError:
+        err = sys.exc_info()[1]
+        assert err is not None
+    else:
+        assert False, "Should not have gotten this far"
+
+
+def test_adaptive_full_fit_in_fails_if_no_width_supplied():
+    try:
+        url_for(adaptive_full_fit_in=True, image_url=IMAGE_URL)
+    except ValueError:
+        err = sys.exc_info()[1]
+        assert err is not None
+    else:
+        assert False, "Should not have gotten this far"
+
+
+def test_full_fit_in_url():
+    '''test_full_fit_in_url
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a width of 200
+        And a height of 300
+        And the full-fit-in flag
+    When
+        I ask my library for an URL
+    Then
+        I get "full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(width=200,
+                  height=300,
+                  full_fit_in=True,
+                  image_url=IMAGE_URL)
+
+    assert url == "full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
+
+
+def test_adaptive_full_fit_in_url():
+    '''test_adaptive_full_fit_in_url
+    Given
+        An image URL of "my.server.com/some/path/to/image.jpg"
+        And a width of 200
+        And a height of 300
+        And the adaptive full-fit-in flag
+    When
+        I ask my library for an URL
+    Then
+        I get "adaptive-full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
+    '''
+    url = url_for(width=200,
+                  height=300,
+                  adaptive_full_fit_in=True,
+                  image_url=IMAGE_URL)
+
+    assert url == "adaptive-full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
+
+
 def test_flip_1():
     '''test_flip_1
     Given
@@ -151,6 +336,7 @@ def test_flip_1():
 
     assert url == "-0x0/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_flip_2():
     '''test_flip_2
     Given
@@ -168,6 +354,7 @@ def test_flip_2():
 
     assert url == "-200x0/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_flop_1():
     '''test_flop_1
     Given
@@ -183,6 +370,7 @@ def test_flop_1():
 
     assert url == "0x-0/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_flop_2():
     '''test_flop_2
     Given
@@ -200,6 +388,7 @@ def test_flop_2():
 
     assert url == "0x-200/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_flip_flop():
     '''test_flip_flop
     Given
@@ -217,6 +406,7 @@ def test_flip_flop():
 
     assert url == "-0x-0/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_flip_flop2():
     '''test_flip_flop2
     Given
@@ -238,6 +428,7 @@ def test_flip_flop2():
 
     assert url == "-200x-300/84996242f65a4d864aceb125e1c4c5ba", url
 
+
 def test_horizontal_alignment():
     '''test_horizontal_alignment
     Given
@@ -253,6 +444,7 @@ def test_horizontal_alignment():
 
     assert url == 'left/84996242f65a4d864aceb125e1c4c5ba', url
 
+
 def test_horizontal_alignment2():
     '''test_horizontal_alignment2
     Given
@@ -268,6 +460,7 @@ def test_horizontal_alignment2():
 
     assert url == '84996242f65a4d864aceb125e1c4c5ba', url
 
+
 def test_vertical_alignment():
     '''test_vertical_alignment
     Given
@@ -283,6 +476,7 @@ def test_vertical_alignment():
 
     assert url == 'top/84996242f65a4d864aceb125e1c4c5ba', url
 
+
 def test_vertical_alignment2():
     '''test_vertical_alignment2
     Given
@@ -298,6 +492,7 @@ def test_vertical_alignment2():
 
     assert url == '84996242f65a4d864aceb125e1c4c5ba', url
 
+
 def test_both_alignments():
     '''test_both_alignments
     Given
@@ -315,26 +510,29 @@ def test_both_alignments():
 
     assert url == 'left/top/84996242f65a4d864aceb125e1c4c5ba', url
 
+
 def test_proper_haligns():
     '''test_proper_haligns'''
     try:
         url_for(halign='wrong', image_url=IMAGE_URL)
-    except ValueError, err:
+    except ValueError as err:
         assert str(err) == 'Only "left", "center" and "right"' + \
                            ' are valid values for horizontal alignment.'
         return True
     assert False, "Should not have gotten this far."
 
+
 def test_proper_valigns():
     '''test_proper_haligns'''
     try:
         url_for(valign='wrong', image_url=IMAGE_URL)
-    except ValueError, err:
+    except ValueError as err:
         assert str(err) == 'Only "top", "middle" and "bottom"' + \
                            ' are valid values for vertical alignment.'
         return True
     assert False, "Should not have gotten this far."
 
+
 def test_proper_meta():
     '''test_proper_meta
     Given
@@ -350,6 +548,31 @@ def test_proper_meta():
 
     assert url == 'meta/84996242f65a4d864aceb125e1c4c5ba', url
 
+
+def test_trim_standard():
+    url = url_for(trim=True,
+                  image_url=IMAGE_URL)
+    assert url == 'trim/84996242f65a4d864aceb125e1c4c5ba', url
+
+
+def test_trim_pixel_and_tolerance():
+    url = url_for(trim=('bottom-right', 15),
+                  image_url=IMAGE_URL)
+    assert url == 'trim:bottom-right:15/84996242f65a4d864aceb125e1c4c5ba', url
+
+
+def test_trim_pixel_only():
+    url = url_for(trim=('top-left', None),
+                  image_url=IMAGE_URL)
+    assert url == 'trim:top-left/84996242f65a4d864aceb125e1c4c5ba', url
+
+
+def test_trim_tolerance_only():
+    url = url_for(trim=(None, 15),
+                  image_url=IMAGE_URL)
+    assert url == 'trim::15/84996242f65a4d864aceb125e1c4c5ba', url
+
+
 def test_manual_crop_1():
     '''test_manual_crop_1
     Given
@@ -366,6 +589,7 @@ def test_manual_crop_1():
 
     assert url == '10x20:30x40/84996242f65a4d864aceb125e1c4c5ba', url
 
+
 def test_manual_crop_2():
     '''test_manual_crop_2
     Given
@@ -382,6 +606,7 @@ def test_manual_crop_2():
 
     assert url == '84996242f65a4d864aceb125e1c4c5ba', url
 
+
 def test_smart_after_alignments():
     '''test_smart_after_alignments
     Given
